==> nextcloud-app-spreed-1%3A7.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/lt_LT.js <==
OC.L10N.register(
    "spreed",
    {
    "Enter name for a new conversation" : "Įveskite naujo pokalbio pavadinimą",
    "New conversation …" : "Naujas pokalbis …",
    "Participants" : "Dalyviai",
    "Exit fullscreen (f)" : "Išeiti iš viso ekrano (f)",
    "Fullscreen (f)" : "Visas ekranas (f)",
    "Copy" : "Kopijuoti",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
    "Error while getting the room ID" : "Klaida gaunant kambario ID",
    "Request password" : "Užklausti slaptažodį",
    "Error requesting the password." : "Klaida užklausiant slaptažodį.",
    "Please enter the password for this call" : "Įveskite šio skambučio slaptažodį",
    "Password required" : "Reikalingas slaptažodis",
    "Password" : "Slaptažodis",
    "Cancel" : "Atsisakyti",
    "Submit" : "Pateikti",
    "Calls are disabled in this conversation." : "Šiame pokalbyje skambinti negalima.",
    "Go to file" : "Pereiti į failą",
    "Share link" : "Dalinimosi nuoroda",
    "Copy link" : "Kopijuoti nuorodą",
    "Change password" : "Pakeisti slaptažodį",
    "Set password" : "Nustatyti slaptažodį",
    "Conversation name" : "Pokalbio pavadinimas",
    "Rename" : "Pervadinti",
    "Link copied!" : "Nuoroda nukopijuota!",
    "Conversation with {name}" : "Pokalbis su {name}",
    "Error occurred while setting password" : "Nustatant slaptažodį, atsirado klaidų",
    "You" : "Jūs",
    "Guest" : "Svečias",
    "No messages yet, start the conversation!" : "Kol kas žinučių nėra, pradėkite pokalbį!",
    "New message …" : "Nauja žinutė …",
    "Send" : "Siųsti",
    "You can not send messages, because the conversation is locked." : "Negalite siųsti žinučių, nes pokalbis užrakintas.",
    "The conversation is locked." : "Pokalbis užrakintas.",
    "[Unknown user name]" : "[Nežinomas naudotojo vardas]",
    "Today" : "Šiandien",
    "Yesterday" : "Vakar",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The message you are trying to send is too long" : "Žinutė, kurią bandote išsiųsti yra pernelyg ilga",
    "Error occurred while sending message" : "Siunčiant žinutę, įvyko klaida",
    "Error while sharing" : "Klaida bendrinant",
    "Edit" : "Taisyti",
    "Say hi to your friends and colleagues!" : "Pasisveikinkite su savo draugais ir kolegomis!",
    "Waiting for {participantName} to join the call …" : "Laukiama kol {participantName} prisijungs prie skambučio …",
    "Waiting for others to join the call …" : "Laukiama kol kiti prisijungs prie skambučio …",
    "Share this link to invite others!" : "Bendrinkite šią nuorodą, norėdami pakviesti kitus!",
    "WebRTC is not supported in your browser :-/" : "Jūsų naršyklėje WebRTC nėra palaikoma :-/",
    "Please use a different browser like Firefox or Chrome" : "Naudokite kitą naršyklę, tokią kaip Firefox ar Chrome",
    "Waiting for camera and microphone permissions" : "Laukiama kameros ir mikrofono leidimų",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Norėdami naudoti šią programėlę, suteikite savo naršyklei prieigą naudoti jūsų kamerą ir mikrofoną.",
    "This conversation has ended" : "Šis pokalbis pasibaigė",
    "Mute audio" : "Nutildyti garsą",
    "Disable video" : "Išjungti vaizdą",
    "Share screen" : "Bendrinti ekraną",
    "Share whole screen" : "Bendrinti visą ekraną",
    "Share a single window" : "Bendrinti vieną langą",
    "Show your screen" : "Rodyti savo ekraną",
    "Stop screensharing" : "Stabdyti ekrano bendrinimą",
    "Mute audio (m)" : "Nutildyti garsą (m)",
    "Unmute audio (m)" : "Įjungti garsą (m)",
    "No audio" : "Nėra jokio garso",
    "Disable video (v)" : "Išjungti vaizdą (v)",
    "Enable video (v)" : "Įjungti vaizdą (v)",
    "No Camera" : "Nėra jokios kameros",
    "Screensharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
    "Screensharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
    "Screensharing options" : "Ekrano bendrinimo parinktys",
    "Sharing your screen only works with Firefox version 52 or newer." : "Ekrano bendrinimas veikia tik naudojant Firefox 52 arba naujesnę versiją.",
    "Screensharing extension is required to share your screen." : "Norint bendrinti ekraną yra reikalingas ekrano bendrinimo plėtinys.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Norėdami bendrinti savo ekraną, naudokite kitą naršyklę, tokią kaip Firefox ar Chrome.",
    "An error occurred while starting screensharing." : "Pradedant ekrano bendrinimą, įvyko klaida.",
    "Enable screensharing" : "Įjungti ekrano bendrinimą",
    "moderator" : "moderatorius",
    "Remove participant" : "Šalinti dalyvį",
    "Error while removing user from room" : "Klaida šalinant naudotoją iš kambario",
    "Add participant …" : "Pridėti dalyvį …",
    "Favorited" : "Pažymėtas svarbiu",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add to favorites" : "Pridėti į mėgstamus",
    "Delete conversation" : "Ištrinti pokalbį",
    "Your screen" : "Jūsų ekranas",
    "Guest's screen" : "Svečio ekranas",
    "Close" : "Užverti",
    "Show screen" : "Rodyti ekraną",
    "Enable video" : "Įjungti vaizdą",
    "Access to microphone & camera is only possible with HTTPS" : "Prieiga prie mikrofono ir kameros yra įmanoma tik naudojant HTTPS",
    "Please move your setup to HTTPS" : "Perkelkite savo sąranką į HTTPS",
    "Access to microphone & camera was denied" : "Prieiga prie mikrofono ir kameros buvo atmesta",
    "WebRTC is not supported in your browser" : "Jūsų naršyklėje WebRTC nėra palaikoma",
    "Error while accessing microphone & camera" : "Klaida, gaunant prieigą prie mikrofono ir kameros",
    "(Duration %s)" : "(Trukmė %s)",
    "_%n guest_::_%n guests_" : ["%n svečias","%n svečiai","%n svečių","%n svečių"],
    "{actor} invited you to {call}" : "{actor} pakvietė jus į {call}",
    "There are currently no commands available." : "Šiuo metu nėra prieinamų komandų.",
    "The command does not exist" : "Komandos nėra",
    "{actor} created the conversation" : "{actor} sukūrė pokalbį",
    "You created the conversation" : "Jūs sukūrėte pokalbį",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} pervadino pokalbį iš \"%1$s\" į \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Jūs pervadinote pokalbį iš \"%1$s\" į \"%2$s\"",
    "{actor} unlocked the conversation" : "{actor} atrakino pokalbį",
    "You unlocked the conversation" : "Jūs atrakinote pokalbį",
    "{actor} locked the conversation" : "{actor} užrakino pokalbį",
    "You locked the conversation" : "Jūs užrakinote pokalbį",
    "{actor} set a password" : "{actor} nustatė slaptažodį",
    "You set a password" : "Jūs nustatėte slaptažodį",
    "{actor} removed the password" : "{actor} pašalino slaptažodį",
    "You removed the password" : "Jūs pašalinote slaptažodį",
    "{actor} added {user}" : "{actor} pridėjo naudotoją {user}",
    "You added {user}" : "Jūs pridėjote naudotoją {user}",
    "{actor} added you" : "{actor} jus pridėjo",
    "{actor} removed {user}" : "{actor} pašalino naudotoją {user}",
    "You removed {user}" : "Jūs pašalinote naudotoją {user}",
    "{actor} removed you" : "{actor} jus pašalino",
    "%s (guest)" : "%s (svečias)",
    "File is not shared, or shared but not with the user" : "Failas nėra bendrinamas arba yra bendrinamas, tačiau ne su naudotoju",
    "%s invited you to a conversation." : "%s jus pakvietė į pokalbį.",
    "You were invited to a conversation." : "Jūs buvote pakviesti į pokalbį.",
    "Click the button below to join." : "Norėdami prisijungti, spustelėkite mygtuką žemiau.",
    "Join »%s«" : "Prisijungti prie »%s«",
    "Private conversation" : "Privatus pokalbis",
    "{user} sent you a private message" : "{user} išsiuntė jums privačią žinutę",
    "{user} mentioned you in a private conversation" : "{user} jus paminėjo privačiame pokalbyje",
    "{user} invited you to a private conversation" : "{user} jus pakvietė į privatų pokalbį",
    "{user} invited you to a group conversation: {call}" : "{user} jus pakvietė į grupės pokalbį: {call}",
    "{user} wants to talk with you" : "{user} nori su jumis pasikalbėti",
    "Conversation not found" : "Pokalbis nerastas",
    "Path is already shared with this room" : "Kelias jau yra bendrinamas su šiuo kambariu",
    "TURN server URL" : "TURN serverio URL",
    "Delete this server" : "Ištrinti šį serverį",
    "STUN server URL" : "STUN serverio URL",
    "TURN server protocols" : "TURN serverio protokolai",
    "UDP and TCP" : "UDP ir TCP",
    "UDP only" : "Tik UDP",
    "TCP only" : "Tik TCP",
    "Test this server" : "Išbandyti šį serverį",
    "Save changes" : "Įrašyti pakeitimus",
    "Saving …" : "Įrašoma …",
    "Saved!" : "Įrašyta!",
    "Commands" : "Komandos",
    "Command" : "Komanda",
    "Script" : "Scenarijus",
    "General settings" : "Bendri nustatymai",
    "Saved" : "Įrašyta",
    "Add a new server" : "Pridėti naują serverį",
    "STUN servers" : "STUN serveriai",
    "TURN servers" : "TURN serveriai",
    "This conversation is password-protected" : "Šis pokalbis yra apsaugotas slaptažodžiu",
    "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
    "TURN server" : "TURN serveris",
    "Android app" : "Android programėlė",
    "iOS app" : "iOS programėlė",
    "Delete server" : "Ištrinti serverį",
    "Add new server" : "Pridėti naują serverį",
    "Test server" : "Išbandyti serverį",
    "New public conversation" : "Naujas viešas pokalbis",
    "New group conversation" : "Naujas grupės pokalbis",
    "Always notify" : "Visada pranešti",
    "Never notify" : "Niekada nepranešti",
    "_%n other guest_::_%n other guests_" : ["ir dar %n svečias","ir dar %n svečiai","ir dar %n svečių","ir dar %n svečias"],
    ", " : ", ",
    "{user} sent a message in a conversation" : "{user} išsiuntė žinutę į pokalbį",
    "A deleted user sent a message in a conversation" : "Ištrintas naudotojas išsiuntė žinutę į pokalbį",
    "A guest sent a message in a conversation" : "Svečias išsiuntė žinutę į pokalbį",
    "%s invited you to a private conversation" : "%s jus pakvietė į privatų pokalbį",
    "%s invited you to a group conversation: %s" : "%s jus pakvietė į grupės pokalbį: %s",
    "%s invited you to a group conversation" : "%s jus pakvietė į grupės pokalbį",
    "{user} invited you to a group conversation" : "{user} jus pakvietė į grupės pokalbį",
    "Someone requested the password to access {file}" : "Kažkas užklausė slaptažodį, kad gautų prieigą prie {file}",
    "Unnamed conversation" : "Pokalbis be pavadinimo",
    "This call is password-protected" : "Šis skambutis yra apsaugotas slaptažodžiu"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-app-spreed-1%3A7.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/lt_LT.js <==
OC.L10N.register(
    "spreed",
    {
    "(Duration %s)" : "(Trukmė %s)",
    "_%n guest_::_%n guests_" : ["%n svečias","%n svečiai","%n svečių","%n svečių"],
    "{actor} invited you to {call}" : "{actor} pakvietė jus į {call}",
    "Guest" : "Svečias",
    "There are currently no commands available." : "Šiuo metu nėra prieinamų komandų.",
    "The command does not exist" : "Komandos nėra",
    "{actor} created the conversation" : "{actor} sukūrė pokalbį",
    "You created the conversation" : "Jūs sukūrėte pokalbį",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} pervadino pokalbį iš \"%1$s\" į \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Jūs pervadinote pokalbį iš \"%1$s\" į \"%2$s\"",
    "{actor} unlocked the conversation" : "{actor} atrakino pokalbį",
    "You unlocked the conversation" : "Jūs atrakinote pokalbį",
    "{actor} locked the conversation" : "{actor} užrakino pokalbį",
    "You locked the conversation" : "Jūs užrakinote pokalbį",
    "{actor} set a password" : "{actor} nustatė slaptažodį",
    "You set a password" : "Jūs nustatėte slaptažodį",
    "{actor} removed the password" : "{actor} pašalino slaptažodį",
    "You removed the password" : "Jūs pašalinote slaptažodį",
    "{actor} added {user}" : "{actor} pridėjo naudotoją {user}",
    "You added {user}" : "Jūs pridėjote naudotoją {user}",
    "{actor} added you" : "{actor} jus pridėjo",
    "{actor} removed {user}" : "{actor} pašalino naudotoją {user}",
    "You removed {user}" : "Jūs pašalinote naudotoją {user}",
    "{actor} removed you" : "{actor} jus pašalino",
    "%s (guest)" : "%s (svečias)",
    "File is not shared, or shared but not with the user" : "Failas nėra bendrinamas arba yra bendrinamas, tačiau ne su naudotoju",
    "%s invited you to a conversation." : "%s jus pakvietė į pokalbį.",
    "You were invited to a conversation." : "Jūs buvote pakviesti į pokalbį.",
    "Click the button below to join." : "Norėdami prisijungti, spustelėkite mygtuką žemiau.",
    "Join »%s«" : "Prisijungti prie »%s«",
    "Private conversation" : "Privatus pokalbis",
    "{user} sent you a private message" : "{user} išsiuntė jums privačią žinutę",
    "{user} mentioned you in a private conversation" : "{user} jus paminėjo privačiame pokalbyje",
    "{user} invited you to a private conversation" : "{user} jus pakvietė į privatų pokalbį",
    "{user} invited you to a group conversation: {call}" : "{user} jus pakvietė į grupės pokalbį: {call}",
    "{user} wants to talk with you" : "{user} nori su jumis pasikalbėti",
    "Conversation not found" : "Pokalbis nerastas",
    "Path is already shared with this room" : "Kelias jau yra bendrinamas su šiuo kambariu",
    "TURN server URL" : "TURN serverio URL",
    "Delete this server" : "Ištrinti šį serverį",
    "STUN server URL" : "STUN serverio URL",
    "TURN server protocols" : "TURN serverio protokolai",
    "UDP and TCP" : "UDP ir TCP",
    "UDP only" : "Tik UDP",
    "TCP only" : "Tik TCP",
    "Test this server" : "Išbandyti šį serverį",
    "[Unknown user name]" : "[Nežinomas naudotojo vardas]",
    "Copy link" : "Kopijuoti nuorodą",
    "Delete conversation" : "Ištrinti pokalbį",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add to favorites" : "Pridėti į mėgstamus",
    "moderator" : "moderatorius",
    "Remove participant" : "Šalinti dalyvį",
    "Share link" : "Dalinimosi nuoroda",
    "Participants" : "Dalyviai",
    "Save changes" : "Įrašyti pakeitimus",
    "Saving …" : "Įrašoma …",
    "Saved!" : "Įrašyta!",
    "Commands" : "Komandos",
    "Command" : "Komanda",
    "Script" : "Scenarijus",
    "General settings" : "Bendri nustatymai",
    "Saved" : "Įrašyta",
    "Add a new server" : "Pridėti naują serverį",
    "STUN servers" : "STUN serveriai",
    "TURN servers" : "TURN serveriai",
    "Say hi to your friends and colleagues!" : "Pasisveikinkite su savo draugais ir kolegomis!",
    "This conversation is password-protected" : "Šis pokalbis yra apsaugotas slaptažodžiu",
    "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
    "Password" : "Slaptažodis",
    "Fullscreen (f)" : "Visas ekranas (f)",
    "TURN server" : "TURN serveris",
    "Android app" : "Android programėlė",
    "iOS app" : "iOS programėlė",
    "Delete server" : "Ištrinti serverį",
    "Add new server" : "Pridėti naują serverį",
    "Test server" : "Išbandyti serverį",
    "New public conversation" : "Naujas viešas pokalbis",
    "New group conversation" : "Naujas grupės pokalbis",
    "New conversation …" : "Naujas pokalbis …",
    "Exit fullscreen (f)" : "Išeiti iš viso ekrano (f)",
    "Copy" : "Kopijuoti",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
    "Error while getting the room ID" : "Klaida gaunant kambario ID",
    "Request password" : "Užklausti slaptažodį",
    "Error requesting the password." : "Klaida užklausiant slaptažodį.",
    "Please enter the password for this call" : "Įveskite šio skambučio slaptažodį",
    "Password required" : "Reikalingas slaptažodis",
    "Cancel" : "Atsisakyti",
    "Submit" : "Pateikti",
    "Change password" : "Pakeisti slaptažodį",
    "Set password" : "Nustatyti slaptažodį",
    "Go to file" : "Pereiti į failą",
    "Conversation name" : "Pokalbio pavadinimas",
    "Rename" : "Pervadinti",
    "Conversation with {name}" : "Pokalbis su {name}",
    "Error occurred while setting password" : "Nustatant slaptažodį, atsirado klaidų",
    "Link copied!" : "Nuoroda nukopijuota!",
    "You" : "Jūs",
    "No messages yet, start the conversation!" : "Kol kas žinučių nėra, pradėkite pokalbį!",
    "New message …" : "Nauja žinutė …",
    "Send" : "Siųsti",
    "Today" : "Šiandien",
    "Yesterday" : "Vakar",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The message you are trying to send is too long" : "Žinutė, kurią bandote išsiųsti yra pernelyg ilga",
    "Error occurred while sending message" : "Siunčiant žinutę, įvyko klaida",
    "Error while sharing" : "Klaida bendrinant",
    "Edit" : "Taisyti",
    "Waiting for {participantName} to join the call …" : "Laukiama kol {participantName} prisijungs prie skambučio …",
    "Waiting for others to join the call …" : "Laukiama kol kiti prisijungs prie skambučio …",
    "Share this link to invite others!" : "Bendrinkite šią nuorodą, norėdami pakviesti kitus!",
    "WebRTC is not supported in your browser :-/" : "Jūsų naršyklėje WebRTC nėra palaikoma :-/",
    "Please use a different browser like Firefox or Chrome" : "Naudokite kitą naršyklę, tokią kaip Firefox ar Chrome",
    "Waiting for camera and microphone permissions" : "Laukiama kameros ir mikrofono leidimų",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Norėdami naudoti šią programėlę, suteikite savo naršyklei prieigą naudoti jūsų kamerą ir mikrofoną.",
    "This conversation has ended" : "Šis pokalbis pasibaigė",
    "Mute audio" : "Nutildyti garsą",
    "Disable video" : "Išjungti vaizdą",
    "Share screen" : "Bendrinti ekraną",
    "Share whole screen" : "Bendrinti visą ekraną",
    "Share a single window" : "Bendrinti vieną langą",
    "Show your screen" : "Rodyti savo ekraną",
    "Stop screensharing" : "Stabdyti ekrano bendrinimą",
    "Unmute audio (m)" : "Įjungti garsą (m)",
    "Mute audio (m)" : "Nutildyti garsą (m)",
    "No audio" : "Nėra jokio garso",
    "Enable video (v)" : "Įjungti vaizdą (v)",
    "Disable video (v)" : "Išjungti vaizdą (v)",
    "No Camera" : "Nėra jokios kameros",
    "Screensharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
    "Screensharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
    "Screensharing options" : "Ekrano bendrinimo parinktys",
    "Sharing your screen only works with Firefox version 52 or newer." : "Ekrano bendrinimas veikia tik naudojant Firefox 52 arba naujesnę versiją.",
    "Screensharing extension is required to share your screen." : "Norint bendrinti ekraną yra reikalingas ekrano bendrinimo plėtinys.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Norėdami bendrinti savo ekraną, naudokite kitą naršyklę, tokią kaip Firefox ar Chrome.",
    "An error occurred while starting screensharing." : "Pradedant ekrano bendrinimą, įvyko klaida.",
    "Enable screensharing" : "Įjungti ekrano bendrinimą",
    "Error while removing user from room" : "Klaida šalinant naudotoją iš kambario",
    "Add participant …" : "Pridėti dalyvį …",
    "Favorited" : "Pažymėtas svarbiu",
    "Always notify" : "Visada pranešti",
    "Never notify" : "Niekada nepranešti",
    "Close" : "Užverti",
    "Show screen" : "Rodyti ekraną",
    "Enable video" : "Įjungti vaizdą",
    "Access to microphone & camera is only possible with HTTPS" : "Prieiga prie mikrofono ir kameros yra įmanoma tik naudojant HTTPS",
    "Please move your setup to HTTPS" : "Perkelkite savo sąranką į HTTPS",
    "Access to microphone & camera was denied" : "Prieiga prie mikrofono ir kameros buvo atmesta",
    "WebRTC is not supported in your browser" : "Jūsų naršyklėje WebRTC nėra palaikoma",
    "Error while accessing microphone & camera" : "Klaida, gaunant prieigą prie mikrofono ir kameros",
    "Guest's screen" : "Svečio ekranas",
    "Your screen" : "Jūsų ekranas",
    "_%n other guest_::_%n other guests_" : ["ir dar %n svečias","ir dar %n svečiai","ir dar %n svečių","ir dar %n svečias"],
    ", " : ", ",
    "{user} sent a message in a conversation" : "{user} išsiuntė žinutę į pokalbį",
    "A deleted user sent a message in a conversation" : "Ištrintas naudotojas išsiuntė žinutę į pokalbį",
    "A guest sent a message in a conversation" : "Svečias išsiuntė žinutę į pokalbį",
    "%s invited you to a private conversation" : "%s jus pakvietė į privatų pokalbį",
    "%s invited you to a group conversation: %s" : "%s jus pakvietė į grupės pokalbį: %s",
    "%s invited you to a group conversation" : "%s jus pakvietė į grupės pokalbį",
    "{user} invited you to a group conversation" : "{user} jus pakvietė į grupės pokalbį",
    "Someone requested the password to access {file}" : "Kažkas užklausė slaptažodį, kad gautų prieigą prie {file}",
    "Unnamed conversation" : "Pokalbis be pavadinimo",
    "This call is password-protected" : "Šis skambutis yra apsaugotas slaptažodžiu",
    "Enter name for a new conversation" : "Įveskite naujo pokalbio pavadinimą",
    "Calls are disabled in this conversation." : "Šiame pokalbyje skambinti negalima.",
    "You can not send messages, because the conversation is locked." : "Negalite siųsti žinučių, nes pokalbis užrakintas.",
    "The conversation is locked." : "Pokalbis užrakintas."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
